@@ -13,6 +13,7 @@ import (
 	"time"
 
 	metal3v1alpha1 "github.com/metal3-io/baremetal-operator/pkg/apis/metal3/v1alpha1"
+	configv1 "github.com/openshift/api/config/v1"
 	mapiv1beta1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
@@ -35,20 +36,25 @@ const (
 )
 
 var GeneralWaitInterval = generalWaitTimeoutInt * time.Second
+var generalProgressUpdateInt = 60 * time.Second
 var LogsUploadPeriod = 5 * time.Minute
-var WaitTimeout = 2 * time.Hour
+var WaitTimeout = 70 * time.Minute
+var NumRetrySendingLogs = 6
 
 // assisted installer controller is added to control installation process after  bootstrap pivot
 // assisted installer will deploy it on installation process
 // as a first step it will wait till nodes are added to cluster and update their status to Done
 
 type ControllerConfig struct {
-	ClusterID            string `envconfig:"CLUSTER_ID" required:"true" `
-	URL                  string `envconfig:"INVENTORY_URL" required:"true"`
-	PullSecretToken      string `envconfig:"PULL_SECRET_TOKEN" required:"true"`
-	SkipCertVerification bool   `envconfig:"SKIP_CERT_VERIFICATION" required:"false" default:"false"`
-	CACertPath           string `envconfig:"CA_CERT_PATH" required:"false" default:""`
-	Namespace            string `enconfig:"NAMESPACE" required:"false" default:"assisted-installer"`
+	ClusterID             string `envconfig:"CLUSTER_ID" required:"true" `
+	URL                   string `envconfig:"INVENTORY_URL" required:"true"`
+	PullSecretToken       string `envconfig:"PULL_SECRET_TOKEN" required:"true"`
+	SkipCertVerification  bool   `envconfig:"SKIP_CERT_VERIFICATION" required:"false" default:"false"`
+	CACertPath            string `envconfig:"CA_CERT_PATH" required:"false" default:""`
+	Namespace             string `envconfig:"NAMESPACE" required:"false" default:"assisted-installer"`
+	OpenshiftVersion      string `envconfig:"OPENSHIFT_VERSION" required:"true"`
+	HighAvailabilityMode  string `envconfig:"HIGH_AVAILABILITY_MODE" required:"false" default:"Full"`
+	WaitForClusterVersion bool   `envconfig:"CHECK_CLUSTER_VERSION" required:"false" default:"false"`
 }
 type Controller interface {
 	WaitAndUpdateNodesStatus(status *ControllerStatus)
@@ -230,15 +236,31 @@ func (c controller) PostInstallConfigs(wg *sync.WaitGroup, status *ControllerSta
 }
 
 func (c controller) postInstallConfigs() error {
+	var err error
 
-	err := utils.WaitForPredicate(WaitTimeout, GeneralWaitInterval, c.addRouterCAToClusterCA)
+	if c.WaitForClusterVersion {
+		err = c.waitingForClusterVersion()
+		if err != nil {
+			return err
+		}
+	}
+
+	err = utils.WaitForPredicate(WaitTimeout, GeneralWaitInterval, c.addRouterCAToClusterCA)
 	if err != nil {
 		return errors.Errorf("Timeout while waiting router ca data")
 	}
 
-	err = utils.WaitForPredicate(WaitTimeout, GeneralWaitInterval, c.unpatchEtcd)
+	unpatch, err := utils.EtcdPatchRequired(c.ControllerConfig.OpenshiftVersion)
 	if err != nil {
-		return errors.Errorf("Timeout while trying to unpatch etcd")
+		return err
+	}
+	if unpatch && c.HighAvailabilityMode != models.ClusterHighAvailabilityModeNone {
+		err = utils.WaitForPredicate(WaitTimeout, GeneralWaitInterval, c.unpatchEtcd)
+		if err != nil {
+			return errors.Errorf("Timeout while trying to unpatch etcd")
+		}
+	} else {
+		c.log.Infof("Skipping etcd unpatch for cluster version %s", c.ControllerConfig.OpenshiftVersion)
 	}
 
 	err = utils.WaitForPredicate(WaitTimeout, GeneralWaitInterval, c.validateConsolePod)
@@ -418,6 +440,50 @@ func (c controller) validateConsolePod() bool {
 	return false
 }
 
+func (c controller) waitingForClusterVersion() error {
+	isClusterVersionAvailable := func() bool {
+		available, msg := c.validateClusterVersion()
+		status := fmt.Sprintf("Cluster version is available: %t , message: %s", available, msg)
+		c.log.Infof(status)
+		if err := c.ic.UpdateClusterInstallProgress(utils.GenerateRequestContext(), c.ClusterID, status); err != nil {
+			c.log.Errorf("Failed to update cluster %s installation progress status: %s", c.ClusterID, err)
+		}
+		return available
+	}
+
+	err := utils.WaitForPredicate(WaitTimeout, generalProgressUpdateInt, isClusterVersionAvailable)
+	if err != nil {
+		return errors.Errorf("Timeout while waiting for cluster version to be available")
+	}
+	return nil
+}
+
+func (c controller) validateClusterVersion() (bool, string) {
+	c.log.Infof("Waiting for cluster version to be available")
+	cv, err := c.kc.GetClusterVersion("version")
+	if err != nil {
+		c.log.WithError(err).Warnf("Failed to get cluster version")
+		return false, ""
+	}
+	conditionsByType := map[configv1.ClusterStatusConditionType]configv1.ClusterOperatorStatusCondition{}
+	// condition type to dict
+	for _, condition := range cv.Status.Conditions {
+		conditionsByType[condition.Type] = condition
+	}
+	// check if it cluster version is available
+	condition, ok := conditionsByType[configv1.OperatorAvailable]
+	if ok && condition.Status == configv1.ConditionTrue {
+		return true, condition.Message
+	}
+	// if not available return message from progressing
+	condition, ok = conditionsByType[configv1.OperatorProgressing]
+	if ok {
+		return false, condition.Message
+	}
+
+	return false, ""
+}
+
 func (c controller) sendCompleteInstallation(isSuccess bool, errorInfo string) {
 	c.log.Infof("Start complete installation step, with params success:%t, error info %s", isSuccess, errorInfo)
 	for {
@@ -440,23 +506,28 @@ func (c controller) sendCompleteInstallation(isSuccess bool, errorInfo string) {
  **/
 func (c controller) uploadSummaryLogs(podName string, namespace string, sinceSeconds int64, isMustGatherEnabled bool) error {
 	var tarentries = make([]utils.TarEntry, 0)
+	var ok bool = true
 	ctx := utils.GenerateRequestContext()
 
-	c.log.Infof("Uploading logs for %s in %s", podName, namespace)
-	if podLogs, err := c.kc.GetPodLogsAsBuffer(namespace, podName, sinceSeconds); err == nil {
-		tarentries = append(tarentries,
-			*utils.NewTarEntry(podLogs, nil, int64(podLogs.Len()), fmt.Sprintf("%s.logs", podName)))
-	}
-
 	if isMustGatherEnabled {
 		c.log.Infof("Uploading oc must-gather logs")
 		if tarfile, err := c.collectMustGatherLogs(ctx); err == nil {
 			if entry, tarerr := utils.NewTarEntryFromFile(tarfile); tarerr == nil {
 				tarentries = append(tarentries, *entry)
 			}
+		} else {
+			ok = false
 		}
 	}
 
+	c.log.Infof("Uploading logs for %s in %s", podName, namespace)
+	if podLogs, err := c.kc.GetPodLogsAsBuffer(namespace, podName, sinceSeconds); err == nil {
+		tarentries = append(tarentries,
+			*utils.NewTarEntry(podLogs, nil, int64(podLogs.Len()), fmt.Sprintf("%s.logs", podName)))
+	} else {
+		ok = false
+	}
+
 	if len(tarentries) == 0 {
 		return errors.New("No logs are available for sending summary logs")
 	}
@@ -473,14 +544,21 @@ func (c controller) uploadSummaryLogs(podName string, namespace string, sinceSec
 			c.log.WithError(err).Warnf("Failed to create tar.gz body of the log uplaod request")
 		}
 	}()
-	// if error will occur in goroutine above
-	//it will close writer and upload will fail
+	// if error will occur in goroutine above, the writer will be closed
+	// and as a result upload will fail
 	err := c.ic.UploadLogs(ctx, c.ClusterID, models.LogsTypeController, pr)
 	if err != nil {
 		utils.RequestIDLogger(ctx, c.log).WithError(err).Error("Failed to upload logs")
+		return err
 	}
 
-	return err
+	if !ok {
+		msg := "Some Logs were not collected in summary"
+		c.log.Errorf(msg)
+		return errors.New(msg)
+	}
+
+	return nil
 }
 
 func (c controller) collectMustGatherLogs(ctx context.Context) (string, error) {
@@ -512,7 +590,7 @@ func (c controller) collectMustGatherLogs(ctx context.Context) (string, error) {
 // Uploading logs every 5 minutes
 // We will take logs of assisted controller and upload them to assisted-service
 // by creating tar gz of them.
-func (c *controller) UploadLogs(ctx context.Context, wg *sync.WaitGroup, status *ControllerStatus) {
+func (c *controller) UploadLogs(ctx context.Context, cancellog context.CancelFunc, wg *sync.WaitGroup, status *ControllerStatus) {
 	defer wg.Done()
 	c.log.Infof("Start sending logs")
 	podName := ""
@@ -522,9 +600,14 @@ func (c *controller) UploadLogs(ctx context.Context, wg *sync.WaitGroup, status
 		case <-ctx.Done():
 			if podName != "" {
 				c.log.Infof("Upload final controller and cluster logs before exit")
-				_ = c.uploadSummaryLogs(podName, c.Namespace, controllerLogsSecondsAgo, status.HasError())
+				_ = utils.WaitForPredicate(WaitTimeout, LogsUploadPeriod, func() bool {
+					err := c.uploadSummaryLogs(podName, c.Namespace, controllerLogsSecondsAgo, status.HasError())
+					if err != nil {
+						c.log.Infof("retry uploading logs in 5 minutes...")
+					}
+					return err == nil
+				})
 			}
-			c.log.Infof("Done uploading logs")
 			return
 		case <-ticker.C:
 			if podName == "" {
@@ -540,12 +623,20 @@ func (c *controller) UploadLogs(ctx context.Context, wg *sync.WaitGroup, status
 				}
 				podName = pods[0].Name
 			}
+
+			if status.HasError() {
+				c.log.Infof("Error detected. Closing logs and aborting...")
+				cancellog()
+				continue
+			}
+
+			//on normal flow, keep updating the controller log output every 5 minutes
+			c.log.Infof("Start uploading controller logs (intermediate snapshot)")
 			err := common.UploadPodLogs(c.kc, c.ic, c.ClusterID, podName, c.Namespace, controllerLogsSecondsAgo, c.log)
 			if err != nil {
 				c.log.WithError(err).Warnf("Failed to upload controller logs")
 				continue
 			}
-			c.log.Infof("Successfully uploaded controller logs (intermediate snapshot) ...")
 		}
 	}
 }
