@@ -112,8 +112,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 	Context("Waiting for 3 nodes", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
@@ -157,8 +158,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	})
 	Context("Waiting for 3 nodes, will appear one by one", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
@@ -205,8 +207,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	})
 	Context("UpdateStatusFails and then succeeds", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
@@ -232,8 +235,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	})
 	Context("ListNodes fails and then succeeds", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
@@ -253,8 +257,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	})
 	Context("validating ApproveCsrs", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
@@ -309,12 +314,15 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 	Context("validating AddRouterCAToClusterCA", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:             "cluster-id",
+			URL:                   "https://assisted-service.com:80",
+			OpenshiftVersion:      "4.7",
+			WaitForClusterVersion: true,
 		}
 		BeforeEach(func() {
 			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
 			GeneralWaitInterval = 1 * time.Second
+			status = &ControllerStatus{}
 		})
 		It("Run addRouterCAToClusterCA happy flow", func() {
 			cmName := "default-ingress-cert"
@@ -347,7 +355,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			res := c.addRouterCAToClusterCA()
 			Expect(res).Should(Equal(false))
 		})
-		It("Run PostInstallConfigs", func() {
+		It("Run PostInstallConfigs - wait for cluster version", func() {
 			cmName := "default-ingress-cert"
 			cmNamespace := "openshift-config-managed"
 			consoleNamespace := "openshift-console"
@@ -368,21 +376,24 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&cluster, nil).Times(1)
 			mockk8sclient.EXPECT().GetConfigMap(cmNamespace, cmName).Return(&cm, nil).Times(1)
 			mockbmclient.EXPECT().UploadIngressCa(gomock.Any(), data["ca-bundle.crt"], c.ClusterID).Return(nil).Times(1)
-			mockk8sclient.EXPECT().UnPatchEtcd().Return(fmt.Errorf("dummy")).Times(1)
-			mockk8sclient.EXPECT().UnPatchEtcd().Return(nil).Times(1)
 			mockk8sclient.EXPECT().GetPods(consoleNamespace, gomock.Any(), "").Return(nil, fmt.Errorf("dummy")).Times(1)
 			mockk8sclient.EXPECT().GetPods(consoleNamespace, gomock.Any(), "").Return([]v1.Pod{{Status: v1.PodStatus{Phase: "Pending"}}}, nil).Times(1)
 			mockk8sclient.EXPECT().GetPods(consoleNamespace, gomock.Any(), "").Return([]v1.Pod{{Status: v1.PodStatus{Phase: "Running"}}}, nil).Times(1)
+			mockk8sclient.EXPECT().GetClusterVersion("version").Return(nil, fmt.Errorf("dummy")).Times(1)
+			mockk8sclient.EXPECT().GetClusterVersion("version").Return(badClusterVersion, nil).Times(1)
+			mockk8sclient.EXPECT().GetClusterVersion("version").Return(goodClusterVersion, nil).Times(1)
 
 			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", true, "").Return(fmt.Errorf("dummy")).Times(1)
 			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", true, "").Return(nil).Times(1)
+			mockbmclient.EXPECT().UpdateClusterInstallProgress(gomock.Any(), gomock.Any(), gomock.Any()).MinTimes(1)
 
 			wg.Add(1)
 			go c.PostInstallConfigs(&wg, status)
 			wg.Wait()
+
 			Expect(status.HasError()).Should(Equal(false))
 		})
-		It("Run PostInstallConfigs failed", func() {
+		It("Run PostInstallConfigs failed - wait for cluster version", func() {
 			WaitTimeout = 2 * time.Second
 			finalizing := models.ClusterStatusFinalizing
 			badClusterVersion := &configv1.ClusterVersion{}
@@ -391,6 +402,66 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			cluster := models.Cluster{Status: &finalizing}
 			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&cluster, nil).Times(1)
 
+			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", false, "Timeout while waiting for cluster "+
+				"version to be available").Return(nil).Times(1)
+
+			wg.Add(1)
+			go c.PostInstallConfigs(&wg, status)
+			wg.Wait()
+			Expect(status.HasError()).Should(Equal(true))
+		})
+	})
+
+	Context("PostInstallConfigs - not waiting for cluster version ", func() {
+		conf := ControllerConfig{
+			ClusterID:             "cluster-id",
+			URL:                   "https://assisted-service.com:80",
+			OpenshiftVersion:      "4.7",
+			WaitForClusterVersion: false,
+		}
+		BeforeEach(func() {
+			c = NewController(l, conf, mockops, mockbmclient, mockk8sclient)
+			GeneralWaitInterval = 1 * time.Second
+			status = &ControllerStatus{}
+		})
+		It("Run PostInstallConfigs - not waiting for cluster version", func() {
+			cmName := "default-ingress-cert"
+			cmNamespace := "openshift-config-managed"
+			consoleNamespace := "openshift-console"
+			data := make(map[string]string)
+			data["ca-bundle.crt"] = "CA"
+			cm := v1.ConfigMap{Data: data}
+			finalizing := models.ClusterStatusFinalizing
+			installing := models.ClusterStatusInstalling
+			badClusterVersion := &configv1.ClusterVersion{}
+			badClusterVersion.Status.Conditions = []configv1.ClusterOperatorStatusCondition{{Type: configv1.OperatorAvailable,
+				Status: configv1.ConditionFalse}}
+			goodClusterVersion := &configv1.ClusterVersion{}
+			goodClusterVersion.Status.Conditions = []configv1.ClusterOperatorStatusCondition{{Type: configv1.OperatorAvailable,
+				Status: configv1.ConditionTrue}}
+			cluster := models.Cluster{Status: &finalizing}
+			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(nil, fmt.Errorf("dummy")).Times(1)
+			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&models.Cluster{Status: &installing}, nil).Times(1)
+			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&cluster, nil).Times(1)
+			mockk8sclient.EXPECT().GetConfigMap(cmNamespace, cmName).Return(&cm, nil).Times(1)
+			mockbmclient.EXPECT().UploadIngressCa(gomock.Any(), data["ca-bundle.crt"], c.ClusterID).Return(nil).Times(1)
+			mockk8sclient.EXPECT().GetPods(consoleNamespace, gomock.Any(), "").Return([]v1.Pod{{Status: v1.PodStatus{Phase: "Running"}}}, nil).Times(1)
+			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", true, "").Return(fmt.Errorf("dummy")).Times(1)
+			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", true, "").Return(nil).Times(1)
+
+			wg.Add(1)
+			c.PostInstallConfigs(&wg, status)
+			wg.Wait()
+			Expect(status.HasError()).Should(Equal(false))
+		})
+		It("Run PostInstallConfigs failed - not waiting for cluster version", func() {
+			WaitTimeout = 2 * time.Second
+			finalizing := models.ClusterStatusFinalizing
+			badClusterVersion := &configv1.ClusterVersion{}
+			badClusterVersion.Status.Conditions = []configv1.ClusterOperatorStatusCondition{{Type: configv1.OperatorAvailable,
+				Status: configv1.ConditionFalse}}
+			cluster := models.Cluster{Status: &finalizing}
+			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&cluster, nil).Times(1)
 			mockk8sclient.EXPECT().GetConfigMap(gomock.Any(), gomock.Any()).Return(nil, fmt.Errorf("aaa")).MinTimes(1)
 			mockbmclient.EXPECT().CompleteInstallation(gomock.Any(), "cluster-id", false,
 				"Timeout while waiting router ca data").Return(nil).Times(1)
@@ -404,8 +475,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 	Context("update BMHs", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			OpenshiftVersion: "4.7",
 		}
 		t := metav1.Unix(98754, 0)
 		bmhStatus := metal3v1alpha1.BareMetalHostStatus{
@@ -485,9 +557,10 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 	Context("Upload logs", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
-			Namespace: "assisted-installer",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			Namespace:        "assisted-installer",
+			OpenshiftVersion: "4.7",
 		}
 		var pod v1.Pod
 		BeforeEach(func() {
@@ -501,7 +574,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockk8sclient.EXPECT().GetPods(conf.Namespace, gomock.Any(), fmt.Sprintf("status.phase=%s", v1.PodRunning)).Return(nil, fmt.Errorf("dummy")).MinTimes(2).MaxTimes(10)
 			ctx, cancel := context.WithCancel(context.Background())
 			wg.Add(1)
-			go c.UploadLogs(ctx, &wg, status)
+			go c.UploadLogs(ctx, cancel, &wg, status)
 			time.Sleep(1 * time.Second)
 			cancel()
 			wg.Wait()
@@ -511,7 +584,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockk8sclient.EXPECT().GetPodLogsAsBuffer(conf.Namespace, "test", gomock.Any()).Return(nil, fmt.Errorf("dummy")).MinTimes(1)
 			ctx, cancel := context.WithCancel(context.Background())
 			wg.Add(1)
-			go c.UploadLogs(ctx, &wg, status)
+			go c.UploadLogs(ctx, cancel, &wg, status)
 			time.Sleep(500 * time.Millisecond)
 			cancel()
 			wg.Wait()
@@ -535,20 +608,23 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 	Context("Upload logs with oc must-gather", func() {
 		conf := ControllerConfig{
-			ClusterID: "cluster-id",
-			URL:       "https://assisted-service.com:80",
-			Namespace: "assisted-installer",
+			ClusterID:        "cluster-id",
+			URL:              "https://assisted-service.com:80",
+			Namespace:        "assisted-installer",
+			OpenshiftVersion: "4.7",
 		}
 
 		var pod v1.Pod
 		var ctx context.Context
 		var cancel context.CancelFunc
 
-		callUploadLogs := func() {
+		callUploadLogs := func(waitTime time.Duration) {
 			wg.Add(1)
-			go c.UploadLogs(ctx, &wg, status)
-			time.Sleep(150 * time.Millisecond)
-			cancel()
+			go c.UploadLogs(ctx, cancel, &wg, status)
+			time.Sleep(waitTime)
+			if !status.HasError() {
+				cancel()
+			}
 			wg.Wait()
 		}
 
@@ -573,13 +649,21 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().GetMustGatherLogs(gomock.Any(), gomock.Any()).Return("../../test_files/tartest.tar.gz", nil).Times(1)
 			mockbmclient.EXPECT().DownloadFile(gomock.Any(), gomock.Any(), gomock.Any()).Return(nil).Times(1)
 			status.Error()
-			callUploadLogs()
+			callUploadLogs(150 * time.Millisecond)
 		})
 
 		It("Validate must-gather logs are not collected with no error", func() {
 			mockops.EXPECT().GetMustGatherLogs(gomock.Any(), gomock.Any()).Times(0)
 			mockbmclient.EXPECT().DownloadFile(gomock.Any(), gomock.Any(), gomock.Any()).Times(0)
-			callUploadLogs()
+			callUploadLogs(150 * time.Millisecond)
+		})
+
+		It("Validate must-gather logs are retried on error", func() {
+			mockops.EXPECT().GetMustGatherLogs(gomock.Any(), gomock.Any()).Return("", fmt.Errorf("failed"))
+			mockops.EXPECT().GetMustGatherLogs(gomock.Any(), gomock.Any()).Return("../../test_files/tartest.tar.gz", nil)
+			mockbmclient.EXPECT().DownloadFile(gomock.Any(), gomock.Any(), gomock.Any()).Return(nil).Times(2)
+			status.Error()
+			callUploadLogs(250 * time.Millisecond)
 		})
 	})
 })
