@@ -40,7 +40,7 @@ func SetConfiguringStatusForHosts(client inventory_client.InventoryClient, inven
 			continue
 		}
 		log.Infof("Verifying if host %s pulled ignition", key)
-		pat := fmt.Sprintf("(%s)", strings.Join(host.IPs, "|"))
+		pat := fmt.Sprintf("(%s).{1,20}(Ignition)", strings.Join(host.IPs, "|"))
 		pattern, err := regexp.Compile(pat)
 		if err != nil {
 			log.WithError(err).Errorf("Failed to compile regex from host %s ips list", host.Host.ID.String())
@@ -110,6 +110,7 @@ func UploadPodLogs(kc k8s_client.K8SClient, ic inventory_client.InventoryClient,
 	//it will close writer and upload will fail
 	ctx := utils.GenerateRequestContext()
 	err = ic.UploadLogs(ctx, clusterId, models.LogsTypeController, pr)
+	log.Infof("Done uploading controller logs to the service")
 	if err != nil {
 		utils.RequestIDLogger(ctx, log).WithError(err).Error("Failed to upload logs")
 		return errors.Wrapf(err, "Failed to upload logs")
