@@ -7,7 +7,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/go-openapi/swag"
 	"github.com/google/uuid"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
@@ -17,7 +16,6 @@ import (
 
 	"github.com/openshift/assisted-installer/src/common"
 	"github.com/openshift/assisted-installer/src/config"
-	"github.com/openshift/assisted-installer/src/ignition"
 	"github.com/openshift/assisted-installer/src/inventory_client"
 	"github.com/openshift/assisted-installer/src/k8s_client"
 	"github.com/openshift/assisted-installer/src/ops"
@@ -27,19 +25,21 @@ import (
 
 const (
 	InstallDir                   = "/opt/install-dir"
+	KubeconfigPathLoopBack       = "/opt/openshift/auth/kubeconfig-loopback"
 	KubeconfigPath               = "/opt/openshift/auth/kubeconfig"
 	minMasterNodes               = 2
 	dockerConfigFile             = "/root/.docker/config.json"
+	assistedControllerPrefix     = "assisted-installer-controller"
 	assistedControllerNamespace  = "assisted-installer"
 	extractRetryCount            = 3
 	waitForeverTimeout           = time.Duration(1<<63 - 1) // wait forever ~ 292 years
 	ovnKubernetes                = "OVNKubernetes"
-	numMasterNodes               = 3
+	networkTypeTimeoutSeconds    = 300
 	singleNodeMasterIgnitionPath = "/opt/openshift/master.ign"
+	numMasterNodes               = 3
 )
 
 var generalWaitTimeout = 30 * time.Second
-var generalWaitInterval = 5 * time.Second
 
 // Installer will run the install operations on the node
 type Installer interface {
@@ -53,17 +53,15 @@ type installer struct {
 	ops             ops.Ops
 	inventoryClient inventory_client.InventoryClient
 	kcBuilder       k8s_client.K8SClientBuilder
-	ign             ignition.Ignition
 }
 
-func NewAssistedInstaller(log *logrus.Logger, cfg config.Config, ops ops.Ops, ic inventory_client.InventoryClient, kcb k8s_client.K8SClientBuilder, ign ignition.Ignition) *installer {
+func NewAssistedInstaller(log *logrus.Logger, cfg config.Config, ops ops.Ops, ic inventory_client.InventoryClient, kcb k8s_client.K8SClientBuilder) *installer {
 	return &installer{
 		log:             log,
 		Config:          cfg,
 		ops:             ops,
 		inventoryClient: ic,
 		kcBuilder:       kcb,
-		ign:             ign,
 	}
 }
 
@@ -71,7 +69,7 @@ func (i *installer) InstallNode() error {
 	i.log.Infof("Installing node with role: %s", i.Config.Role)
 
 	i.UpdateHostInstallProgress(models.HostStageStartingInstallation, i.Config.Role)
-	i.Config.Device = i.ops.EvaluateDiskSymlink(i.Config.Device)
+
 	i.log.Infof("Start cleaning up device %s", i.Device)
 	err := i.cleanupInstallDevice()
 	if err != nil {
@@ -85,16 +83,15 @@ func (i *installer) InstallNode() error {
 		return err
 	}
 	ctx, cancel := context.WithCancel(context.Background())
-	bootstrapErrGroup, _ := errgroup.WithContext(ctx)
+	errs, _ := errgroup.WithContext(ctx)
 	//cancel the context in case this method ends
 	defer cancel()
 	isBootstrap := false
 	if i.Config.Role == string(models.HostRoleBootstrap) && i.HighAvailabilityMode != models.ClusterHighAvailabilityModeNone {
 		isBootstrap = true
-		bootstrapErrGroup.Go(func() error {
-			return i.startBootstrap()
+		errs.Go(func() error {
+			return i.runBootstrap(ctx)
 		})
-		go i.updateConfiguringStatus(ctx)
 		i.Config.Role = string(models.HostRoleMaster)
 	}
 
@@ -106,6 +103,7 @@ func (i *installer) InstallNode() error {
 		if err != nil {
 			return err
 		}
+		i.Config.Role = string(models.HostRoleMaster)
 	} else {
 		ignitionPath, err = i.downloadHostIgnition()
 		if err != nil {
@@ -117,74 +115,24 @@ func (i *installer) InstallNode() error {
 	if err = i.writeImageToDisk(ignitionPath); err != nil {
 		return err
 	}
-
-	if err = i.ops.SetBootOrder(i.Device); err != nil {
-		i.log.WithError(err).Warnf("Failed to set boot order")
-		// Ignore the error for now so it doesn't fail the installation in case it fails
-		//return err
-	}
-
 	if isBootstrap {
-		if err = bootstrapErrGroup.Wait(); err != nil {
-			i.log.Errorf("Bootstrap failed %s", err)
-			return err
-		}
-		if err = i.waitForControlPlane(ctx); err != nil {
-			return err
-		}
-		i.log.Info("Setting bootstrap node new role to master")
-
-	} else if i.Config.Role == string(models.HostRoleWorker) {
-		// Wait for 2 masters to be ready before rebooting
-		if err = i.workerWaitFor2ReadyMasters(ctx); err != nil {
+		i.UpdateHostInstallProgress(models.HostStageWaitingForControlPlane, "")
+		if err = errs.Wait(); err != nil {
+			i.log.Error(err)
 			return err
 		}
 	}
-	//upload host logs and report log status before reboot
-	i.log.Infof("Uploading logs and reporting status before rebooting the node %s for cluster %s", i.Config.HostID, i.Config.ClusterID)
-	i.inventoryClient.HostLogProgressReport(ctx, i.Config.ClusterID, i.Config.HostID, models.LogsStateRequested)
 	_, err = i.ops.UploadInstallationLogs(isBootstrap || i.HighAvailabilityMode == models.ClusterHighAvailabilityModeNone)
 	if err != nil {
 		i.log.Errorf("upload installation logs %s", err)
 	}
-	//update installation progress
 	i.UpdateHostInstallProgress(models.HostStageRebooting, "")
-	//reboot
 	if err = i.ops.Reboot(); err != nil {
 		return err
 	}
 	return nil
 }
 
-//updateSingleNodeIgnition will download the host ignition config and add the files under storage
-func (i *installer) updateSingleNodeIgnition(singleNodeIgnitionPath string) error {
-	hostIgnitionPath, err := i.downloadHostIgnition()
-	if err != nil {
-		return err
-	}
-	fmt.Println(i.ign)
-	singleNodeconfig, err := i.ign.ParseIgnitionFile(singleNodeIgnitionPath)
-	if err != nil {
-		return err
-	}
-	hostConfig, err := i.ign.ParseIgnitionFile(hostIgnitionPath)
-	if err != nil {
-		return err
-	}
-	// TODO: update this once we can get the full host specific overrides we have in the ignition
-	// Remove the Config part since we only want the rest of the overrides
-	hostConfig.Ignition.Config = ignition.EmptyIgnitionConfig
-	merged, mergeErr := i.ign.MergeIgnitionConfig(singleNodeconfig, hostConfig)
-	if mergeErr != nil {
-		return errors.Wrapf(mergeErr, "failed to apply host ignition config overrides")
-	}
-	err = i.ign.WriteIgnitionFile(singleNodeIgnitionPath, merged)
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
 func (i *installer) writeImageToDisk(ignitionPath string) error {
 	i.UpdateHostInstallProgress(models.HostStageWritingImageToDisk, "")
 	interval := time.Second
@@ -199,14 +147,32 @@ func (i *installer) writeImageToDisk(ignitionPath string) error {
 	return nil
 }
 
-func (i *installer) startBootstrap() error {
-	i.log.Infof("Running bootstrap")
-	// This is required for the log collection command to work since it will try to mount this directory
-	// This directory is also required by `generateSshKeyPair` as it will place the key there
-	if err := i.ops.Mkdir(sshDir); err != nil {
-		i.log.WithError(err).Error("Failed to create SSH dir")
+func (i *installer) runBootstrap(ctx context.Context) error {
+	ctxLocal, cancel := context.WithCancel(ctx)
+	defer func() {
+		cancel()
+	}()
+	go i.updateConfiguringStatus(ctxLocal)
+
+	err := i.startBootstrap()
+	if err != nil {
+		i.log.Errorf("Bootstrap failed %s", err)
 		return err
 	}
+	kc, err := i.kcBuilder(KubeconfigPathLoopBack, i.log)
+	if err != nil {
+		i.log.Error(err)
+		return err
+	}
+	if err = i.waitForControlPlane(ctx, kc); err != nil {
+		return err
+	}
+	i.log.Info("Setting bootstrap node new role to master")
+	return nil
+}
+
+func (i *installer) startBootstrap() error {
+	i.log.Infof("Running bootstrap")
 	ignitionFileName := "bootstrap.ign"
 	ignitionPath, err := i.getFileFromService(ignitionFileName)
 	if err != nil {
@@ -301,6 +267,10 @@ func (i *installer) extractIgnitionToFS(ignitionPath string) (err error) {
 
 func (i *installer) generateSshKeyPair() error {
 	i.log.Info("Generating new SSH key pair")
+	if err := i.ops.Mkdir(sshDir); err != nil {
+		i.log.WithError(err).Error("Failed to create SSH dir")
+		return err
+	}
 	if _, err := i.ops.ExecPrivilegeCommand(utils.NewLogWriter(i.log), "ssh-keygen", "-q", "-f", sshKeyPath, "-N", ""); err != nil {
 		i.log.WithError(err).Error("Failed to generate SSH key pair")
 		return err
@@ -334,30 +304,15 @@ func (i *installer) downloadHostIgnition() (string, error) {
 	return dest, err
 }
 
-func (i *installer) waitForNetworkType(kc k8s_client.K8SClient) error {
-	return utils.WaitForPredicate(waitForeverTimeout, 5*time.Second, func() bool {
+func waitForNetworkType(kc k8s_client.K8SClient) error {
+	return utils.WaitForPredicate(networkTypeTimeoutSeconds*time.Second, time.Second, func() bool {
 		_, err := kc.GetNetworkType()
-		if err != nil {
-			i.log.WithError(err).Error("Failed to get network type")
-		}
 		return err == nil
 	})
 }
 
-func (i *installer) waitForControlPlane(ctx context.Context) error {
-	err := i.ops.ReloadHostFile("/etc/resolv.conf")
-	if err != nil {
-		i.log.WithError(err).Error("Failed to reload resolv.conf")
-		return err
-	}
-	kc, err := i.kcBuilder(KubeconfigPath, i.log)
-	if err != nil {
-		i.log.Error(err)
-		return err
-	}
-	i.UpdateHostInstallProgress(models.HostStageWaitingForControlPlane, "")
-
-	if err = i.waitForMinMasterNodes(ctx, kc); err != nil {
+func (i *installer) waitForControlPlane(ctx context.Context, kc k8s_client.K8SClient) error {
+	if err := i.waitForMinMasterNodes(ctx, kc); err != nil {
 		return err
 	}
 
@@ -378,7 +333,7 @@ func (i *installer) waitForControlPlane(ctx context.Context) error {
 	i.waitForBootkube(ctx)
 
 	// waiting for controller pod to be running
-	if err := i.waitForController(kc); err != nil {
+	if err := i.waitForController(); err != nil {
 		i.log.Error(err)
 		return err
 	}
@@ -386,88 +341,39 @@ func (i *installer) waitForControlPlane(ctx context.Context) error {
 	return nil
 }
 
-func numDoneMasters(cluster *models.Cluster) int {
-	numDoneMasters := 0
-	for _, h := range cluster.Hosts {
-		if h.Role == models.HostRoleMaster && h.Progress.CurrentStage == models.HostStageDone {
-			numDoneMasters++
-		}
-	}
-	return numDoneMasters
-}
-
-func (i *installer) workerWaitFor2ReadyMasters(ctx context.Context) error {
-	i.log.Info("Waiting for 2 ready masters")
-	i.UpdateHostInstallProgress(models.HostStageWaitingForControlPlane, "")
-	for {
-		cluster, err := i.inventoryClient.GetCluster(ctx)
-		if err != nil {
-			i.log.WithError(err).Errorf("Getting cluster %s", i.ClusterID)
-			return err
-		}
-		if swag.StringValue(cluster.Kind) == models.ClusterKindAddHostsCluster || numDoneMasters(cluster) >= minMasterNodes {
-			return nil
-		}
-		time.Sleep(generalWaitInterval)
-	}
-}
-
-func (i *installer) shouldControlPlaneReplicasPatchApplied(kc k8s_client.K8SClient) (bool, error) {
-	controlPlanePatchRequired, err := utils.IsVersionLessThan47(i.Config.OpenshiftVersion)
-	if err != nil {
-		i.log.WithError(err).Errorf("Failed to get compare OCP version")
-		return false, err
-	}
-	if !controlPlanePatchRequired {
-		i.log.Info("Control plane replicas patch not required due to Openshift version not less than 4.7")
-		return false, nil
-	}
-	if err = i.waitForNetworkType(kc); err != nil {
-		i.log.WithError(err).Error("failed to wait for network type")
-		return false, err
+func (i *installer) waitForMinMasterNodes(ctx context.Context, kc k8s_client.K8SClient) error {
+	if err := waitForNetworkType(kc); err != nil {
+		i.log.Error("failed to get network type")
+		return err
 	}
 	nt, err := kc.GetNetworkType()
 	if err != nil {
-		i.log.WithError(err).Error("failed to get network type")
-		return false, err
-	}
-	if nt != ovnKubernetes {
-		i.log.Info("Control plane replicas patch not required due to network type not OVNKubernetes")
-		return false, nil
-	}
-	// OVNKubernetes waits the number that is defined in controlPlane.Replicas to be
-	// available before starting OVN.  Since assisted installer has a bootstrap node
-	// that later becomes a master, there is a need to patch the install-config to
-	// set the controlPlane.replicas to 2 until all masters which are not the
-	// bootstrap are ready.
-	// On single node this is not the case since bootstrap in place is used.
-	// Therefore, the patch is not relevant to single node.
-	origControlPlaneReplicas, err := kc.GetControlPlaneReplicas()
-	if err != nil {
-		i.log.WithError(err).Error("Failed to get control plane replicas")
-		return false, err
-	}
-	if origControlPlaneReplicas != numMasterNodes {
-		i.log.Infof("Control plane replicas patch not required due to control plane replicas %d not equal to %d", origControlPlaneReplicas, numMasterNodes)
-		return false, nil
-	}
-	i.log.Info("Applying control plane replicas patch")
-	return true, nil
-}
-
-func (i *installer) waitForMinMasterNodes(ctx context.Context, kc k8s_client.K8SClient) error {
-	shouldPatchControlPlaneReplicas, err := i.shouldControlPlaneReplicasPatchApplied(kc)
-	if err != nil {
+		i.log.Error("failed to get network type")
 		return err
 	}
-	if shouldPatchControlPlaneReplicas {
-		if err = kc.PatchControlPlaneReplicas(); err != nil {
-			i.log.WithError(err).Error("Failed to patch control plane replicas")
+	var origControlPlaneReplicas int
+	if nt == ovnKubernetes {
+		// OVNKubernetes waits the number that is defined in controlPlane.Replicas to be
+		// available before starting OVN.  Since assisted installer has a bootstrap node
+		// that later becomes a master, there is a need to patch the install-config to
+		// set the controlPlane.replicas to 2 until all masters which are not the
+		// bootstrap are ready.
+		// On single node this is not the case since bootstrap in place is used.
+		// Therefore, the patch is not relevant to single node.
+		if origControlPlaneReplicas, err = kc.GetControlPlaneReplicas(); err != nil {
+			i.log.WithError(err).Error("Failed to get control plane replicas")
 			return err
 		}
+		if origControlPlaneReplicas == numMasterNodes {
+			if err = kc.PatchControlPlaneReplicas(); err != nil {
+				i.log.WithError(err).Error("Failed to patch control plane replicas")
+				return err
+			}
+		}
 	}
+
 	i.waitForMasterNodes(ctx, minMasterNodes, kc)
-	if shouldPatchControlPlaneReplicas {
+	if nt == ovnKubernetes && origControlPlaneReplicas == numMasterNodes {
 		if err = kc.UnPatchControlPlaneReplicas(); err != nil {
 			i.log.WithError(err).Error("Failed to unPatch control plane replicas")
 			return err
@@ -481,7 +387,7 @@ func (i *installer) UpdateHostInstallProgress(newStage models.HostStage, info st
 	log := utils.RequestIDLogger(ctx, i.log)
 	log.Infof("Updating node installation stage: %s - %s", newStage, info)
 	if i.HostID != "" {
-		if err := i.inventoryClient.UpdateHostInstallProgress(ctx, i.Config.InfraEnvID, i.Config.HostID, newStage, info); err != nil {
+		if err := i.inventoryClient.UpdateHostInstallProgress(ctx, i.HostID, newStage, info); err != nil {
 			log.Errorf("Failed to update node installation stage, %s", err)
 		}
 	}
@@ -489,19 +395,17 @@ func (i *installer) UpdateHostInstallProgress(newStage models.HostStage, info st
 
 func (i *installer) waitForBootkube(ctx context.Context) {
 	i.log.Infof("Waiting for bootkube to complete")
-	i.UpdateHostInstallProgress(models.HostStageWaitingForBootkube, "")
-
 	for {
 		select {
 		case <-ctx.Done():
 			i.log.Info("Context cancelled, terminating wait for bootkube\n")
 			return
-		case <-time.After(generalWaitInterval):
+		case <-time.After(time.Second * time.Duration(5)):
 			// check if bootkube is done every 5 seconds
 			if _, err := i.ops.ExecPrivilegeCommand(nil, "stat", "/opt/openshift/.bootkube.done"); err == nil {
 				// in case bootkube is done log the status and return
 				i.log.Info("bootkube service completed")
-				out, _ := i.ops.ExecPrivilegeCommand(nil, "systemctl", "status", "bootkube.service")
+				out, _ := i.ops.ExecPrivilegeCommand(utils.NewLogWriter(i.log), "systemctl", "status", "bootkube.service")
 				i.log.Info(out)
 				return
 			}
@@ -509,63 +413,41 @@ func (i *installer) waitForBootkube(ctx context.Context) {
 	}
 }
 
-func (i *installer) waitForController(kc k8s_client.K8SClient) error {
-	i.log.Infof("Waiting for controller to be ready")
-	i.UpdateHostInstallProgress(models.HostStageWaitingForController, "waiting for controller pod ready event")
-
-	events := map[string]string{}
-	tickerUploadLogs := time.NewTicker(5 * time.Minute)
-	tickerWaitForController := time.NewTicker(generalWaitInterval)
-	for {
-		select {
-		case <-tickerWaitForController.C:
-			if i.wasControllerReadyEventSet(kc, events) {
-				i.log.Infof("Assisted controller is ready")
-				i.inventoryClient.ClusterLogProgressReport(utils.GenerateRequestContext(), i.ClusterID, models.LogsStateRequested)
-				i.uploadControllerLogs(kc)
-				return nil
+func (i *installer) waitForController() error {
+	i.log.Infof("Waiting for controller pod to start running")
+	i.UpdateHostInstallProgress(models.HostStageWaitingForControlPlane, "waiting for controller pod")
+	err := i.ops.ReloadHostFile("/etc/resolv.conf")
+	if err != nil {
+		i.log.WithError(err).Error("Failed to reload resolv.conf")
+		return err
+	}
+	kc, err := i.kcBuilder(KubeconfigPath, i.log)
+	if err != nil {
+		i.log.WithError(err).Errorf("Failed to create kc client from %s", KubeconfigPath)
+		return err
+	}
+	predicate := func() bool {
+		controllerPod := common.GetPodInStatus(kc, assistedControllerPrefix, assistedControllerNamespace,
+			map[string]string{"job-name": assistedControllerPrefix}, v1.PodRunning, i.log)
+		if controllerPod != nil {
+			// uploading logs here cause we will finish installing bootstrap in couple of seconds
+			// just didn't wanted to start handling this logic in other place
+			// controller must be running for at least couple of minutes before this code so it will cover 90% of the cases
+			// if we will see that it is not enough, we will change the place.
+			err = common.UploadPodLogs(kc, i.inventoryClient, i.ClusterID, controllerPod.Name, assistedControllerNamespace, common.ControllerLogsSecondsAgo, i.log)
+			// if failed to upload logs, log why and continue
+			if err != nil {
+				i.log.WithError(err).Warnf("Failed to upload controller logs")
 			}
-		case <-tickerUploadLogs.C:
-			i.uploadControllerLogs(kc)
 		}
+		return controllerPod != nil
 	}
-}
-
-func (i *installer) uploadControllerLogs(kc k8s_client.K8SClient) {
-	controllerPod := common.GetPodInStatus(kc, common.AssistedControllerPrefix, assistedControllerNamespace,
-		map[string]string{"job-name": common.AssistedControllerPrefix}, v1.PodRunning, i.log)
-	if controllerPod != nil {
-		//do not report the progress of this pre-fetching of controller logs to the service
-		//since controller may not be ready at all and we'll end up waiting for a timeout to expire
-		//in the service with no good reason before giving up on the logs
-		//when controller is ready - it will report its log progress by itself
-		err := common.UploadPodLogs(kc, i.inventoryClient, i.ClusterID, controllerPod.Name, assistedControllerNamespace, common.ControllerLogsSecondsAgo, i.log)
-		// if failed to upload logs, log why and continue
-		if err != nil {
-			i.log.WithError(err).Warnf("Failed to upload controller logs")
-		}
+	// wait forever
+	err = utils.WaitForPredicate(waitForeverTimeout, 5*time.Second, predicate)
+	if err != nil {
+		return errors.Errorf("Timeout while waiting for controller pod to be running")
 	}
-}
-
-func (i *installer) wasControllerReadyEventSet(kc k8s_client.K8SClient, previousEvents map[string]string) bool {
-	newEvents, errEvents := kc.ListEvents(assistedControllerNamespace)
-	if errEvents != nil {
-		logrus.WithError(errEvents).Warnf("Failed to get controller events")
-		return false
-	}
-
-	readyEventFound := false
-	for _, event := range newEvents.Items {
-		if _, ok := previousEvents[string(event.UID)]; !ok {
-			i.log.Infof("Assisted controller new event: %s", event.Message)
-			previousEvents[string(event.UID)] = event.Name
-		}
-		if event.Name == common.AssistedControllerIsReadyEvent {
-			readyEventFound = true
-		}
-	}
-
-	return readyEventFound
+	return nil
 }
 
 // wait for minimum master nodes to be in ready status
@@ -585,10 +467,7 @@ func (i *installer) waitForMasterNodes(ctx context.Context, minMasterNodes int,
 			i.log.Warnf("Still waiting for master nodes: %v", err)
 			return false
 		}
-		if err = i.updateReadyMasters(nodes, &readyMasters, inventoryHostsMap); err != nil {
-			i.log.WithError(err).Warnf("Failed to update ready with masters")
-			return false
-		}
+		i.updateReadyMasters(nodes, &readyMasters, inventoryHostsMap)
 		i.log.Infof("Found %d ready master nodes", len(readyMasters))
 		if len(readyMasters) >= minMasterNodes {
 			i.log.Infof("Waiting for master nodes - Done")
@@ -602,7 +481,7 @@ func (i *installer) waitForMasterNodes(ctx context.Context, minMasterNodes int,
 		case <-ctx.Done():
 			i.log.Info("Context cancelled, terminating wait for master nodes\n")
 			return
-		case <-time.After(generalWaitInterval):
+		case <-time.After(time.Second * time.Duration(5)):
 			// check if we have sufficient master nodes is done every 5 seconds
 			if sufficientMasterNodes() {
 				return
@@ -632,28 +511,30 @@ func (i *installer) getInventoryHostsMap(hostsMap map[string]inventory_client.Ho
 	return hostsMap, nil
 }
 
-func (i *installer) updateReadyMasters(nodes *v1.NodeList, readyMasters *[]string, inventoryHostsMap map[string]inventory_client.HostData) error {
+func (i *installer) updateReadyMasters(nodes *v1.NodeList, readyMasters *[]string, inventoryHostsMap map[string]inventory_client.HostData) {
 	nodeNameAndCondition := map[string][]v1.NodeCondition{}
 	for _, node := range nodes.Items {
 		nodeNameAndCondition[node.Name] = node.Status.Conditions
-		if common.IsK8sNodeIsReady(node) && !funk.ContainsString(*readyMasters, node.Name) {
-			ctx := utils.GenerateRequestContext()
-			log := utils.RequestIDLogger(ctx, i.log)
-			log.Infof("Found a new ready master node %s with id %s", node.Name, node.Status.NodeInfo.SystemUUID)
-			*readyMasters = append(*readyMasters, node.Name)
-			host, ok := inventoryHostsMap[strings.ToLower(node.Name)]
-			if !ok {
-				return fmt.Errorf("Node %s is not in inventory hosts", node.Name)
-			}
-			ctx = utils.GenerateRequestContext()
-			if err := i.inventoryClient.UpdateHostInstallProgress(ctx, host.Host.InfraEnvID.String(), host.Host.ID.String(), models.HostStageJoined, ""); err != nil {
-				utils.RequestIDLogger(ctx, i.log).Errorf("Failed to update node installation status, %s", err)
+		for _, cond := range node.Status.Conditions {
+			if cond.Type == v1.NodeReady && cond.Status == v1.ConditionTrue &&
+				!funk.ContainsString(*readyMasters, node.Status.NodeInfo.SystemUUID) {
+				ctx := utils.GenerateRequestContext()
+				log := utils.RequestIDLogger(ctx, i.log)
+				log.Infof("Found a new ready master node %s with id %s", node.Name, node.Status.NodeInfo.SystemUUID)
+				*readyMasters = append(*readyMasters, node.Status.NodeInfo.SystemUUID)
+				host, ok := inventoryHostsMap[strings.ToLower(node.Name)]
+				if !ok {
+					log.Warnf("Node %s is not in inventory hosts", node.Name)
+					break
+				}
+				ctx = utils.GenerateRequestContext()
+				if err := i.inventoryClient.UpdateHostInstallProgress(ctx, host.Host.ID.String(), models.HostStageJoined, ""); err != nil {
+					utils.RequestIDLogger(ctx, i.log).Errorf("Failed to update node installation status, %s", err)
+				}
 			}
 		}
 	}
-
 	i.log.Infof("Found %d master nodes: %+v", len(nodes.Items), nodeNameAndCondition)
-	return nil
 }
 
 func (i *installer) cleanupInstallDevice() error {
@@ -740,12 +621,6 @@ func (i *installer) createSingleNodeMasterIgnition() (string, error) {
 		i.log.Errorf("Failed to find single node master ignition: %s", err)
 		return "", err
 	}
-	i.Config.Role = string(models.HostRoleMaster)
-	err = i.updateSingleNodeIgnition(singleNodeMasterIgnitionPath)
-	if err != nil {
-		return "", err
-	}
-
 	return singleNodeMasterIgnitionPath, nil
 }
 
@@ -753,7 +628,7 @@ func (i *installer) checkLocalhostName() error {
 	i.log.Infof("Start checking localhostname")
 	hostname, err := i.ops.GetHostname()
 	if err != nil {
-		i.log.Errorf("Failed to get hostname from kernel, err %s157", err)
+		i.log.Errorf("Failed to get hostname from kernel, err %s", err)
 		return err
 	}
 	if hostname != "localhost" {
