@@ -11,15 +11,16 @@ import (
 	"time"
 
 	"github.com/go-openapi/strfmt"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+
+	"github.com/pkg/errors"
+
+	v1 "k8s.io/api/core/v1"
+
 	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
-	"github.com/openshift/assisted-installer/src/common"
-	"github.com/openshift/assisted-installer/src/ignition"
-	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
-	v1 "k8s.io/api/core/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/openshift/assisted-installer/src/config"
 	"github.com/openshift/assisted-installer/src/inventory_client"
@@ -40,26 +41,16 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		mockops            *ops.MockOps
 		mockbmclient       *inventory_client.MockInventoryClient
 		mockk8sclient      *k8s_client.MockK8SClient
-		mockIgnition       *ignition.MockIgnition
 		installerObj       *installer
 		hostId             = "host-id"
-		infraEnvId         = "infra-env-id"
 		bootstrapIgn       = "bootstrap.ign"
 		openShiftVersion   = "4.7"
 		inventoryNamesHost map[string]inventory_client.HostData
 		kubeNamesIds       map[string]string
-		events             v1.EventList
 	)
-	generalWaitTimeout = 100 * time.Millisecond
-	generalWaitInterval = 5 * time.Millisecond
+	generalWaitTimeout = 100 * time.Minute
 	device := "/dev/vda"
-	events = v1.EventList{TypeMeta: metav1.TypeMeta{},
-		ListMeta: metav1.ListMeta{}, Items: []v1.Event{{TypeMeta: metav1.TypeMeta{}, ObjectMeta: metav1.ObjectMeta{UID: "7916fa89-ea7a-443e-a862-b3e930309f65", Name: common.AssistedControllerIsReadyEvent}, Message: "aaaa"}}}
 	l.SetOutput(ioutil.Discard)
-	evaluateDiskSymlinkSuccess := func() {
-		mockops.EXPECT().EvaluateDiskSymlink(device).Return(device).Times(1)
-	}
-
 	mkdirSuccess := func(filepath string) {
 		mockops.EXPECT().Mkdir(filepath).Return(nil).Times(1)
 	}
@@ -70,19 +61,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		mockbmclient.EXPECT().DownloadHostIgnition(gomock.Any(), hostID, filepath.Join(InstallDir, fileName)).Return(nil).Times(1)
 	}
 
-	reportLogProgressSuccess := func() {
-		mockbmclient.EXPECT().HostLogProgressReport(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes()
-		mockbmclient.EXPECT().ClusterLogProgressReport(gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes()
-	}
-
-	singleNodeMergeIgnitionSuccess := func() {
-		conf := ignition.EmptyIgnition
-		mockIgnition.EXPECT().ParseIgnitionFile("/opt/install-dir/master-host-id.ign").Return(&conf, nil).Times(1)
-		mockIgnition.EXPECT().ParseIgnitionFile(singleNodeMasterIgnitionPath).Return(&conf, nil).Times(1)
-		mockIgnition.EXPECT().MergeIgnitionConfig(gomock.Any(), gomock.Any()).Return(&conf, nil).Times(1)
-		mockIgnition.EXPECT().WriteIgnitionFile(singleNodeMasterIgnitionPath, gomock.Any()).Return(nil).Times(1)
-	}
-
 	cleanInstallDevice := func() {
 		mockops.EXPECT().GetVGByPV(device).Return("", nil).Times(1)
 	}
@@ -90,9 +68,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	updateProgressSuccess := func(stages [][]string) {
 		for _, stage := range stages {
 			if len(stage) == 2 {
-				mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStage(stage[0]), stage[1]).Return(nil).Times(1)
+				mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), hostId, models.HostStage(stage[0]), stage[1]).Return(nil).Times(1)
 			} else {
-				mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStage(stage[0]), "").Return(nil).Times(1)
+				mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), hostId, models.HostStage(stage[0]), "").Return(nil).Times(1)
 			}
 		}
 	}
@@ -101,23 +79,17 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		mockops.EXPECT().WriteImageToDisk(filepath.Join(InstallDir, "master-host-id.ign"), device, mockbmclient, extra).Return(nil).Times(1)
 	}
 
-	setBootOrderSuccess := func(extra interface{}) {
-		mockops.EXPECT().SetBootOrder(device).Return(nil).Times(1)
-	}
-
 	uploadLogsSuccess := func(bootstrap bool) {
 		mockops.EXPECT().UploadInstallationLogs(bootstrap).Return("dummy", nil).Times(1)
 	}
 
 	waitForControllerSuccessfully := func(clusterId string) {
-		mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStageWaitingForController, "waiting for controller pod ready event").Return(nil).Times(1)
+		mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), hostId, models.HostStageWaitingForControlPlane, "waiting for controller pod").Return(nil).Times(1)
 		mockk8sclient.EXPECT().GetPods("assisted-installer", gomock.Any(), "").Return([]v1.Pod{{TypeMeta: metav1.TypeMeta{},
-			ObjectMeta: metav1.ObjectMeta{Name: common.AssistedControllerPrefix + "aasdasd"},
+			ObjectMeta: metav1.ObjectMeta{Name: assistedControllerPrefix + "aasdasd"},
 			Status:     v1.PodStatus{Phase: "Running"}}}, nil).Times(1)
 		r := bytes.NewBuffer([]byte("test"))
-		mockk8sclient.EXPECT().GetPodLogsAsBuffer(assistedControllerNamespace, common.AssistedControllerPrefix+"aasdasd", gomock.Any()).Return(r, nil).Times(1)
-		mockk8sclient.EXPECT().ListEvents(assistedControllerNamespace).Return(nil, fmt.Errorf("dummy")).Times(1)
-		mockk8sclient.EXPECT().ListEvents(assistedControllerNamespace).Return(&events, nil).Times(1)
+		mockk8sclient.EXPECT().GetPodLogsAsBuffer(assistedControllerNamespace, assistedControllerPrefix+"aasdasd", gomock.Any()).Return(r, nil).Times(1)
 		mockbmclient.EXPECT().UploadLogs(gomock.Any(), clusterId, models.LogsTypeController, gomock.Any()).Return(nil).Times(1)
 	}
 
@@ -133,14 +105,12 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		mockops = ops.NewMockOps(ctrl)
 		mockbmclient = inventory_client.NewMockInventoryClient(ctrl)
 		mockk8sclient = k8s_client.NewMockK8SClient(ctrl)
-		mockIgnition = ignition.NewMockIgnition(ctrl)
-		nodesInfraEnvId := strfmt.UUID("7916fa89-ea7a-443e-a862-b3e930309f50")
 		node0Id := strfmt.UUID("7916fa89-ea7a-443e-a862-b3e930309f65")
 		node1Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f238")
 		node2Id := strfmt.UUID("b898d516-3e16-49d0-86a5-0ad5bd04e3ed")
-		inventoryNamesHost = map[string]inventory_client.HostData{"node0": {Host: &models.Host{InfraEnvID: nodesInfraEnvId, ID: &node0Id}, IPs: []string{"192.168.126.10"}},
-			"node1": {Host: &models.Host{InfraEnvID: nodesInfraEnvId, ID: &node1Id}, IPs: []string{"192.168.126.11"}},
-			"node2": {Host: &models.Host{InfraEnvID: nodesInfraEnvId, ID: &node2Id}, IPs: []string{"192.168.126.12"}}}
+		inventoryNamesHost = map[string]inventory_client.HostData{"node0": {Host: &models.Host{ID: &node0Id}, IPs: []string{"192.168.126.10"}},
+			"node1": {Host: &models.Host{ID: &node1Id}, IPs: []string{"192.168.126.11"}},
+			"node2": {Host: &models.Host{ID: &node2Id}, IPs: []string{"192.168.126.12"}}}
 	})
 	k8sBuilder := func(configPath string, logger *logrus.Logger) (k8s_client.K8SClient, error) {
 		return mockk8sclient, nil
@@ -150,7 +120,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 		conf := config.Config{Role: string(models.HostRoleBootstrap),
 			ClusterID:        "cluster-id",
-			InfraEnvID:       "infra-env-id",
 			HostID:           "host-id",
 			Device:           "/dev/vda",
 			URL:              "https://assisted-service.com:80",
@@ -158,8 +127,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			MCOImage:         "quay.io/openshift-release-dev/ocp-v4.0-art-dev@sha256:dc1a34f55c712b2b9c5e5a14dd85e67cbdae11fd147046ac2fef9eaf179ab221",
 		}
 		BeforeEach(func() {
-			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder, mockIgnition)
-			evaluateDiskSymlinkSuccess()
+			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder)
 		})
 		mcoImage := conf.MCOImage
 		extractIgnitionToFS := func(out string, err error) {
@@ -197,11 +165,11 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockk8sclient.EXPECT().ListMasterNodes().Return(GetKubeNodes(map[string]string{}), nil).Times(1)
 			kubeNamesIds = map[string]string{"node0": "7916fa89-ea7a-443e-a862-b3e930309f65"}
 			mockk8sclient.EXPECT().ListMasterNodes().Return(GetKubeNodes(kubeNamesIds), nil).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), inventoryNamesHost["node0"].Host.InfraEnvID.String(), inventoryNamesHost["node0"].Host.ID.String(), models.HostStageJoined, "").Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), inventoryNamesHost["node0"].Host.ID.String(), models.HostStageJoined, "").Times(1)
 			kubeNamesIds = map[string]string{"node0": "7916fa89-ea7a-443e-a862-b3e930309f65",
 				"node1": "eb82821f-bf21-4614-9a3b-ecb07929f238"}
 			mockk8sclient.EXPECT().ListMasterNodes().Return(GetKubeNodes(kubeNamesIds), nil).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), inventoryNamesHost["node1"].Host.InfraEnvID.String(), inventoryNamesHost["node1"].Host.ID.String(), models.HostStageJoined, "").Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), inventoryNamesHost["node1"].Host.ID.String(), models.HostStageJoined, "").Times(1)
 		}
 		getNetworkTypeSuccessOpenshiftSDN := func() {
 			mockk8sclient.EXPECT().GetNetworkType().Return("OpenshiftSDN", nil).Times(2)
@@ -222,7 +190,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().PrepareController().Return(nil).Times(1)
 		}
 		waitForBootkubeSuccess := func() {
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStageWaitingForBootkube, "").Return(nil).Times(1)
 			mockops.EXPECT().ExecPrivilegeCommand(gomock.Any(), "stat", "/opt/openshift/.bootkube.done").Return("OK", nil).Times(1)
 		}
 		bootkubeStatusSuccess := func() {
@@ -233,6 +200,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().ExtractFromIgnition(filepath.Join(InstallDir, bootstrapIgn), dockerConfigFile).Return(nil).Times(1)
 		}
 		generateSshKeyPairSuccess := func() {
+			mkdirSuccess(sshDir)
 			mockops.EXPECT().ExecPrivilegeCommand(gomock.Any(), "ssh-keygen", "-q", "-f", sshKeyPath, "-N", "").Return("OK", nil).Times(1)
 		}
 		createOpenshiftSshManifestSuccess := func() {
@@ -241,7 +209,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 		bootstrapSetup := func() {
 			cleanInstallDevice()
-			mkdirSuccess(sshDir)
 			mkdirSuccess(InstallDir)
 			downloadFileSuccess(bootstrapIgn)
 			extractSecretFromIgnitionSuccess()
@@ -250,87 +217,70 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			createOpenshiftSshManifestSuccess()
 			daemonReload(nil)
 		}
-		for _, version := range []string{"4.6", "4.6.16", "4.7", "4.7.1", "4.7-pre-release", "4.8"} {
-			Context(version, func() {
-				BeforeEach(func() {
-					conf.OpenshiftVersion = version
-				})
-				AfterEach(func() {
-					conf.OpenshiftVersion = openShiftVersion
-				})
-				It("bootstrap role happy flow", func() {
-					updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
-						{string(models.HostStageWaitingForControlPlane)},
-						{string(models.HostStageInstalling), string(models.HostRoleMaster)},
-						{string(models.HostStageWritingImageToDisk)},
-						{string(models.HostStageRebooting)},
-					})
-					bootstrapSetup()
-					checkLocalHostname("not localhost", nil)
-					restartNetworkManager(nil)
-					prepareControllerSuccess()
-					startServicesSuccess()
-					if conf.OpenshiftVersion == "4.6" {
-						getNetworkTypeSuccessOpenshiftSDN()
-					}
-					WaitMasterNodesSucccess()
-					waitForBootkubeSuccess()
-					bootkubeStatusSuccess()
-					resolvConfSuccess()
-					waitForControllerSuccessfully(conf.ClusterID)
-					//HostRoleMaster flow:
-					downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
-					writeToDiskSuccess(gomock.Any())
-					reportLogProgressSuccess()
-					setBootOrderSuccess(gomock.Any())
-					uploadLogsSuccess(true)
-					rebootSuccess()
-					ret := installerObj.InstallNode()
-					Expect(ret).Should(BeNil())
-				})
-				It("bootstrap role happy flow ovn-kubernetes", func() {
-					updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
-						{string(models.HostStageWaitingForControlPlane)},
-						{string(models.HostStageInstalling), string(models.HostRoleMaster)},
-						{string(models.HostStageWritingImageToDisk)},
-						{string(models.HostStageRebooting)},
-					})
-					bootstrapSetup()
-					checkLocalHostname("localhost", nil)
-					restartNetworkManager(nil)
-					prepareControllerSuccess()
-					startServicesSuccess()
-					if conf.OpenshiftVersion == "4.6" {
-						getNetworkTypeSuccessOVNKubernetes()
-						getControlPlaneReplicasSuccess()
-						patchControlPlaneReplicasSuccess()
-						unpatchControlPlaneReplicasSuccess()
-					}
-					WaitMasterNodesSucccess()
-					waitForBootkubeSuccess()
-					bootkubeStatusSuccess()
-					resolvConfSuccess()
-					waitForControllerSuccessfully(conf.ClusterID)
-					//HostRoleMaster flow:
-					downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
-					writeToDiskSuccess(gomock.Any())
-					setBootOrderSuccess(gomock.Any())
-					uploadLogsSuccess(true)
-					reportLogProgressSuccess()
-					rebootSuccess()
-					ret := installerObj.InstallNode()
-					Expect(ret).Should(BeNil())
-				})
+
+		It("bootstrap role happy flow", func() {
+			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
+				{string(models.HostStageWaitingForControlPlane)},
+				{string(models.HostStageInstalling), string(models.HostRoleMaster)},
+				{string(models.HostStageWritingImageToDisk)},
+				{string(models.HostStageRebooting)},
 			})
-		}
+			bootstrapSetup()
+			checkLocalHostname("not localhost", nil)
+			restartNetworkManager(nil)
+			prepareControllerSuccess()
+			startServicesSuccess()
+			getNetworkTypeSuccessOpenshiftSDN()
+			WaitMasterNodesSucccess()
+			waitForBootkubeSuccess()
+			bootkubeStatusSuccess()
+			resolvConfSuccess()
+			waitForControllerSuccessfully(conf.ClusterID)
+			//HostRoleMaster flow:
+			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
+			writeToDiskSuccess(gomock.Any())
+			uploadLogsSuccess(true)
+			rebootSuccess()
+			ret := installerObj.InstallNode()
+			Expect(ret).Should(BeNil())
+		})
+		It("bootstrap role happy flow ovn-kubernetes", func() {
+			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
+				{string(models.HostStageWaitingForControlPlane)},
+				{string(models.HostStageInstalling), string(models.HostRoleMaster)},
+				{string(models.HostStageWritingImageToDisk)},
+				{string(models.HostStageRebooting)},
+			})
+			bootstrapSetup()
+			checkLocalHostname("localhost", nil)
+			restartNetworkManager(nil)
+			prepareControllerSuccess()
+			startServicesSuccess()
+			getNetworkTypeSuccessOVNKubernetes()
+			getControlPlaneReplicasSuccess()
+			patchControlPlaneReplicasSuccess()
+			unpatchControlPlaneReplicasSuccess()
+			WaitMasterNodesSucccess()
+			waitForBootkubeSuccess()
+			bootkubeStatusSuccess()
+			resolvConfSuccess()
+			waitForControllerSuccessfully(conf.ClusterID)
+			//HostRoleMaster flow:
+			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
+			writeToDiskSuccess(gomock.Any())
+			uploadLogsSuccess(true)
+			rebootSuccess()
+			ret := installerObj.InstallNode()
+			Expect(ret).Should(BeNil())
+		})
 		It("bootstrap role creating SSH manifest failed", func() {
 			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
+				{string(models.HostStageWaitingForControlPlane)},
 				{string(models.HostStageInstalling), string(models.HostRoleMaster)},
 				{string(models.HostStageWritingImageToDisk)},
 			})
 			cleanInstallDevice()
 			mkdirSuccess(InstallDir)
-			mkdirSuccess(sshDir)
 			downloadFileSuccess(bootstrapIgn)
 			extractSecretFromIgnitionSuccess()
 			extractIgnitionToFS("Success", nil)
@@ -340,7 +290,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			//HostRoleMaster flow:
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			writeToDiskSuccess(gomock.Any())
-			setBootOrderSuccess(gomock.Any())
 			ret := installerObj.InstallNode()
 			Expect(ret).To(HaveOccurred())
 		})
@@ -357,6 +306,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			restartNetworkManager(nil)
 			prepareControllerSuccess()
 			startServicesSuccess()
+			getNetworkTypeSuccessOpenshiftSDN()
 			WaitMasterNodesSucccess()
 			waitForBootkubeSuccess()
 			bootkubeStatusSuccess()
@@ -365,9 +315,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			//HostRoleMaster flow:
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			writeToDiskSuccess(gomock.Any())
-			setBootOrderSuccess(gomock.Any())
 			uploadLogsSuccess(true)
-			reportLogProgressSuccess()
 			rebootSuccess()
 			ret := installerObj.InstallNode()
 			Expect(ret).Should(BeNil())
@@ -376,14 +324,13 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
 				{string(models.HostStageInstalling), string(models.HostRoleMaster)},
 				{string(models.HostStageWritingImageToDisk)},
+				{string(models.HostStageWaitingForControlPlane)},
 			})
 			cleanInstallDevice()
 			mkdirSuccess(InstallDir)
-			mkdirSuccess(sshDir)
 			downloadFileSuccess(bootstrapIgn)
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			writeToDiskSuccess(gomock.Any())
-			setBootOrderSuccess(gomock.Any())
 			extractSecretFromIgnitionSuccess()
 			extractIgnitionToFS("extract failure", fmt.Errorf("extract failed"))
 			extractIgnitionToFS("extract failure", fmt.Errorf("extract failed"))
@@ -396,6 +343,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
 				{string(models.HostStageInstalling), string(models.HostRoleMaster)},
 				{string(models.HostStageWritingImageToDisk)},
+				{string(models.HostStageWaitingForControlPlane)},
 			})
 			bootstrapSetup()
 			checkLocalHostname("not localhost", nil)
@@ -404,53 +352,36 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			//HostRoleMaster flow:
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			writeToDiskSuccess(gomock.Any())
-			setBootOrderSuccess(gomock.Any())
 			ret := installerObj.InstallNode()
 			Expect(ret).Should(Equal(err))
 		})
-	})
-	Context("Bootstrap role waiting for control plane", func() {
+		It("waitForController reload resolv.conf failed", func() {
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), hostId, models.HostStageWaitingForControlPlane, "waiting for controller pod").Return(nil).Times(1)
+			mockops.EXPECT().ReloadHostFile("/etc/resolv.conf").Return(fmt.Errorf("dummy")).Times(1)
 
-		conf := config.Config{Role: string(models.HostRoleBootstrap),
-			ClusterID:        "cluster-id",
-			InfraEnvID:       "infra-env-id",
-			HostID:           "host-id",
-			Device:           "/dev/vda",
-			URL:              "https://assisted-service.com:80",
-			OpenshiftVersion: openShiftVersion,
-			MCOImage:         "quay.io/openshift-release-dev/ocp-v4.0-art-dev@sha256:dc1a34f55c712b2b9c5e5a14dd85e67cbdae11fd147046ac2fef9eaf179ab221",
-		}
-		BeforeEach(func() {
-			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder, mockIgnition)
-		})
-		It("waitForControlPlane reload resolv.conf failed", func() {
-			mockops.EXPECT().ReloadHostFile("/etc/resolv.conf").Return(fmt.Errorf("failed to load file")).Times(1)
-
-			err := installerObj.waitForControlPlane(context.Background())
+			err := installerObj.waitForController()
 			Expect(err).To(HaveOccurred())
 		})
-
 		It("waitForController reload get pods fails then succeeds", func() {
-			reportLogProgressSuccess()
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStageWaitingForController, "waiting for controller pod ready event").Return(nil).Times(1)
+			resolvConfSuccess()
 			mockk8sclient.EXPECT().GetPods("assisted-installer", gomock.Any(), "").Return(nil, fmt.Errorf("dummy")).Times(1)
-			mockk8sclient.EXPECT().ListEvents(assistedControllerNamespace).Return(&events, nil).Times(1)
-			err := installerObj.waitForController(mockk8sclient)
+			waitForControllerSuccessfully(conf.ClusterID)
+			err := installerObj.waitForController()
 			Expect(err).NotTo(HaveOccurred())
 		})
 		It("Configuring state", func() {
 			var logs string
+			generalWaitTimeout = 100 * time.Millisecond
 			logsInBytes, _ := ioutil.ReadFile("../../test_files/mcs_logs.txt")
 			logs = string(logsInBytes)
-			infraEnvID := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f250")
 			node0Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f238")
 			node1Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f239")
 			node2Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f240")
 
-			testInventoryIdsIps := map[string]inventory_client.HostData{"node0": {Host: &models.Host{InfraEnvID: infraEnvID, ID: &node0Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}},
+			testInventoryIdsIps := map[string]inventory_client.HostData{"node0": {Host: &models.Host{ID: &node0Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}},
 				IPs: []string{"192.168.126.10", "192.168.11.122", "fe80::5054:ff:fe9a:4738"}},
-				"node1": {Host: &models.Host{InfraEnvID: infraEnvID, ID: &node1Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.11", "192.168.11.123", "fe80::5054:ff:fe9a:4739"}},
-				"node2": {Host: &models.Host{InfraEnvID: infraEnvID, ID: &node2Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.12", "192.168.11.124", "fe80::5054:ff:fe9a:4740"}}}
+				"node1": {Host: &models.Host{ID: &node1Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.11", "192.168.11.123", "fe80::5054:ff:fe9a:4739"}},
+				"node2": {Host: &models.Host{ID: &node2Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.12", "192.168.11.124", "fe80::5054:ff:fe9a:4740"}}}
 			mockbmclient.EXPECT().GetEnabledHostsNamesHosts(gomock.Any(), gomock.Any()).Return(nil, fmt.Errorf("dummy")).Times(1)
 			mockbmclient.EXPECT().GetEnabledHostsNamesHosts(gomock.Any(), gomock.Any()).Return(testInventoryIdsIps, nil).Times(1)
 			mockops.EXPECT().GetMCSLogs().Return("", fmt.Errorf("dummy")).Times(1)
@@ -458,9 +389,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().GetMCSLogs().Return("dummy logs", nil).Times(1)
 			mockops.EXPECT().GetMCSLogs().Return(logs, nil).AnyTimes()
 
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), gomock.Any(), gomock.Any(), models.HostStageConfiguring, gomock.Any()).Return(fmt.Errorf("dummy")).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f250", "eb82821f-bf21-4614-9a3b-ecb07929f240", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f250", "eb82821f-bf21-4614-9a3b-ecb07929f239", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), gomock.Any(), models.HostStageConfiguring, gomock.Any()).Return(fmt.Errorf("dummy")).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f240", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f239", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
 
 			ctx, cancel := context.WithTimeout(context.Background(), 3*time.Second)
 			defer cancel()
@@ -469,15 +400,15 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		})
 		It("Configuring state, all hosts were set", func() {
 			var logs string
+			generalWaitTimeout = 100 * time.Millisecond
 			logsInBytes, _ := ioutil.ReadFile("../../test_files/mcs_logs.txt")
 			logs = string(logsInBytes)
-			infraEnvId := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f250")
 			node1Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f239")
 			node2Id := strfmt.UUID("eb82821f-bf21-4614-9a3b-ecb07929f240")
 
 			testInventoryIdsIps := map[string]inventory_client.HostData{
-				"node1": {Host: &models.Host{InfraEnvID: infraEnvId, ID: &node1Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.11", "192.168.11.123", "fe80::5054:ff:fe9a:4739"}},
-				"node2": {Host: &models.Host{InfraEnvID: infraEnvId, ID: &node2Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.12", "192.168.11.124", "fe80::5054:ff:fe9a:4740"}}}
+				"node1": {Host: &models.Host{ID: &node1Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.11", "192.168.11.123", "fe80::5054:ff:fe9a:4739"}},
+				"node2": {Host: &models.Host{ID: &node2Id, Progress: &models.HostProgressInfo{CurrentStage: models.HostStageRebooting}}, IPs: []string{"192.168.126.12", "192.168.11.124", "fe80::5054:ff:fe9a:4740"}}}
 			mockbmclient.EXPECT().GetEnabledHostsNamesHosts(gomock.Any(), gomock.Any()).Return(nil, fmt.Errorf("dummy")).Times(1)
 			mockbmclient.EXPECT().GetEnabledHostsNamesHosts(gomock.Any(), gomock.Any()).Return(testInventoryIdsIps, nil).Times(1)
 			mockops.EXPECT().GetMCSLogs().Return("", fmt.Errorf("dummy")).Times(1)
@@ -485,9 +416,9 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().GetMCSLogs().Return("dummy logs", nil).Times(1)
 			mockops.EXPECT().GetMCSLogs().Return(logs, nil).AnyTimes()
 
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), gomock.Any(), gomock.Any(), models.HostStageConfiguring, gomock.Any()).Return(fmt.Errorf("dummy")).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f250", "eb82821f-bf21-4614-9a3b-ecb07929f240", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f250", "eb82821f-bf21-4614-9a3b-ecb07929f239", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), gomock.Any(), models.HostStageConfiguring, gomock.Any()).Return(fmt.Errorf("dummy")).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f240", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
+			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), "eb82821f-bf21-4614-9a3b-ecb07929f239", models.HostStageConfiguring, gomock.Any()).Return(nil).Times(1)
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
 			installerObj.updateConfiguringStatus(ctx)
@@ -497,7 +428,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		installerArgs := []string{"-n", "--append-karg", "nameserver=8.8.8.8"}
 		conf := config.Config{Role: string(models.HostRoleMaster),
 			ClusterID:        "cluster-id",
-			InfraEnvID:       "infra-env-id",
 			HostID:           "host-id",
 			Device:           "/dev/vda",
 			URL:              "https://assisted-service.com:80",
@@ -505,9 +435,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			InstallerArgs:    installerArgs,
 		}
 		BeforeEach(func() {
-			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder, mockIgnition)
-			evaluateDiskSymlinkSuccess()
-
+			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder)
 		})
 		It("master role happy flow", func() {
 			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
@@ -519,9 +447,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mkdirSuccess(InstallDir)
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			writeToDiskSuccess(installerArgs)
-			setBootOrderSuccess(gomock.Any())
 			uploadLogsSuccess(false)
-			reportLogProgressSuccess()
 			rebootSuccess()
 			ret := installerObj.InstallNode()
 			Expect(ret).Should(BeNil())
@@ -593,9 +519,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mkdirSuccess(InstallDir)
 			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			uploadLogsSuccess(false)
-			reportLogProgressSuccess()
 			writeToDiskSuccess(installerArgs)
-			setBootOrderSuccess(gomock.Any())
 			err := fmt.Errorf("failed to reboot")
 			mockops.EXPECT().Reboot().Return(err).Times(1)
 			ret := installerObj.InstallNode()
@@ -605,47 +529,25 @@ var _ = Describe("installer HostRoleMaster role", func() {
 	Context("Worker role", func() {
 		conf := config.Config{Role: string(models.HostRoleWorker),
 			ClusterID:        "cluster-id",
-			InfraEnvID:       "infra-env-id",
 			HostID:           "host-id",
 			Device:           "/dev/vda",
 			URL:              "https://assisted-service.com:80",
 			OpenshiftVersion: openShiftVersion,
 		}
 		BeforeEach(func() {
-			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder, mockIgnition)
-			evaluateDiskSymlinkSuccess()
+			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder)
 		})
 		It("worker role happy flow", func() {
 			updateProgressSuccess([][]string{{string(models.HostStageStartingInstallation), conf.Role},
 				{string(models.HostStageInstalling), conf.Role},
 				{string(models.HostStageWritingImageToDisk)},
-				{string(models.HostStageWaitingForControlPlane)},
 				{string(models.HostStageRebooting)},
 			})
-			cluster := models.Cluster{
-				Hosts: []*models.Host{
-					{
-						Role: models.HostRoleMaster,
-						Progress: &models.HostProgressInfo{
-							CurrentStage: models.HostStageDone,
-						},
-					},
-					{
-						Role: models.HostRoleMaster,
-						Progress: &models.HostProgressInfo{
-							CurrentStage: models.HostStageDone,
-						},
-					},
-				},
-			}
-			mockbmclient.EXPECT().GetCluster(gomock.Any()).Return(&cluster, nil).Times(1)
 			cleanInstallDevice()
 			mkdirSuccess(InstallDir)
 			downloadHostIgnitionSuccess(hostId, "worker-host-id.ign")
 			mockops.EXPECT().WriteImageToDisk(filepath.Join(InstallDir, "worker-host-id.ign"), device, mockbmclient, nil).Return(nil).Times(1)
-			setBootOrderSuccess(gomock.Any())
 			// failure must do nothing
-			reportLogProgressSuccess()
 			mockops.EXPECT().UploadInstallationLogs(false).Return("", errors.Errorf("Dummy")).Times(1)
 			rebootSuccess()
 			ret := installerObj.InstallNode()
@@ -656,7 +558,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 
 		conf := config.Config{Role: string(models.HostRoleMaster),
 			ClusterID:            "cluster-id",
-			InfraEnvID:           "infra-env-id",
 			HostID:               "host-id",
 			Device:               "/dev/vda",
 			URL:                  "https://assisted-service.com:80",
@@ -665,8 +566,7 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			HighAvailabilityMode: models.ClusterHighAvailabilityModeNone,
 		}
 		BeforeEach(func() {
-			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder, mockIgnition)
-			evaluateDiskSymlinkSuccess()
+			installerObj = NewAssistedInstaller(l, conf, mockops, mockbmclient, k8sBuilder)
 		})
 		mcoImage := conf.MCOImage
 		extractIgnitionToFS := func(out string, err error) {
@@ -703,7 +603,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			mockops.EXPECT().PrepareController().Return(nil).Times(1)
 		}
 		waitForBootkubeSuccess := func() {
-			mockbmclient.EXPECT().UpdateHostInstallProgress(gomock.Any(), infraEnvId, hostId, models.HostStageWaitingForBootkube, "").Return(nil).Times(1)
 			mockops.EXPECT().ExecPrivilegeCommand(gomock.Any(), "stat", "/opt/openshift/.bootkube.done").Return("OK", nil).Times(1)
 		}
 		bootkubeStatusSuccess := func() {
@@ -715,7 +614,6 @@ var _ = Describe("installer HostRoleMaster role", func() {
 		singleNodeBootstrapSetup := func() {
 			cleanInstallDevice()
 			mkdirSuccess(InstallDir)
-			mkdirSuccess(sshDir)
 			downloadFileSuccess(bootstrapIgn)
 			extractSecretFromIgnitionSuccess()
 			extractIgnitionToFS("Success", nil)
@@ -741,12 +639,8 @@ var _ = Describe("installer HostRoleMaster role", func() {
 			bootkubeStatusSuccess()
 			//HostRoleMaster flow:
 			verifySingleNodeMasterIgnitionSuccess()
-			singleNodeMergeIgnitionSuccess()
-			downloadHostIgnitionSuccess(hostId, "master-host-id.ign")
 			mockops.EXPECT().WriteImageToDisk(singleNodeMasterIgnitionPath, device, mockbmclient, nil).Return(nil).Times(1)
-			setBootOrderSuccess(gomock.Any())
 			uploadLogsSuccess(true)
-			reportLogProgressSuccess()
 			rebootSuccess()
 			ret := installerObj.InstallNode()
 			Expect(ret).Should(BeNil())
