@@ -25,7 +25,6 @@ import (
 	"github.com/openshift/assisted-installer/src/utils"
 	"github.com/openshift/assisted-service/client"
 	"github.com/openshift/assisted-service/client/installer"
-	"github.com/openshift/assisted-service/client/operators"
 	"github.com/openshift/assisted-service/models"
 	"github.com/openshift/assisted-service/pkg/auth"
 	aserror "github.com/openshift/assisted-service/pkg/error"
@@ -43,24 +42,19 @@ const (
 type InventoryClient interface {
 	DownloadFile(ctx context.Context, filename string, dest string) error
 	DownloadHostIgnition(ctx context.Context, hostID string, dest string) error
-	UpdateHostInstallProgress(ctx context.Context, infraEnvId string, hostId string, newStage models.HostStage, info string) error
+	UpdateHostInstallProgress(ctx context.Context, hostId string, newStage models.HostStage, info string) error
 	GetEnabledHostsNamesHosts(ctx context.Context, log logrus.FieldLogger) (map[string]HostData, error)
 	UploadIngressCa(ctx context.Context, ingressCA string, clusterId string) error
 	GetCluster(ctx context.Context) (*models.Cluster, error)
-	GetClusterMonitoredOperator(ctx context.Context, clusterId, operatorName string) (*models.MonitoredOperator, error)
-	GetClusterMonitoredOLMOperators(ctx context.Context, clusterId string) ([]models.MonitoredOperator, error)
 	CompleteInstallation(ctx context.Context, clusterId string, isSuccess bool, errorInfo string) error
 	GetHosts(ctx context.Context, log logrus.FieldLogger, skippedStatuses []string) (map[string]HostData, error)
 	UploadLogs(ctx context.Context, clusterId string, logsType models.LogsType, upfile io.Reader) error
-	ClusterLogProgressReport(ctx context.Context, clusterId string, progress models.LogsState)
-	HostLogProgressReport(ctx context.Context, infraEnvId string, hostId string, progress models.LogsState)
-	UpdateClusterOperator(ctx context.Context, clusterId string, operatorName string, operatorStatus models.OperatorStatus, operatorStatusInfo string) error
+	UpdateClusterInstallProgress(ctx context.Context, clusterId string, progress string) error
 }
 
 type inventoryClient struct {
 	ai        *client.AssistedInstall
 	clusterId strfmt.UUID
-	logger    *logrus.Logger
 }
 
 type HostData struct {
@@ -135,7 +129,7 @@ func CreateInventoryClientWithDelay(clusterId string, inventoryURL string, pullS
 
 	clientConfig.AuthInfo = auth.AgentAuthHeaderWriter(pullSecret)
 	assistedInstallClient := client.New(clientConfig)
-	return &inventoryClient{assistedInstallClient, strfmt.UUID(clusterId), logger}, nil
+	return &inventoryClient{assistedInstallClient, strfmt.UUID(clusterId)}, nil
 }
 
 func RetryConnectionRefusedErr() rehttp.RetryFn {
@@ -183,7 +177,6 @@ func (c *inventoryClient) DownloadFile(ctx context.Context, filename string, des
 	defer func() {
 		fo.Close()
 	}()
-	c.logger.Infof("Downloading file %s to %s", filename, dest)
 	_, err = c.ai.Installer.DownloadClusterFiles(ctx, c.createDownloadParams(filename), fo)
 	return aserror.GetAssistedError(err)
 }
@@ -207,8 +200,8 @@ func (c *inventoryClient) DownloadHostIgnition(ctx context.Context, hostID strin
 	return aserror.GetAssistedError(err)
 }
 
-func (c *inventoryClient) UpdateHostInstallProgress(ctx context.Context, infraEnvId, hostId string, newStage models.HostStage, info string) error {
-	_, err := c.ai.Installer.V2UpdateHostInstallProgress(ctx, c.createUpdateHostInstallProgressParams(infraEnvId, hostId, newStage, info))
+func (c *inventoryClient) UpdateHostInstallProgress(ctx context.Context, hostId string, newStage models.HostStage, info string) error {
+	_, err := c.ai.Installer.UpdateHostInstallProgress(ctx, c.createUpdateHostInstallProgressParams(hostId, newStage, info))
 	return aserror.GetAssistedError(err)
 }
 
@@ -221,40 +214,12 @@ func (c *inventoryClient) UploadIngressCa(ctx context.Context, ingressCA string,
 func (c *inventoryClient) GetCluster(ctx context.Context) (*models.Cluster, error) {
 	cluster, err := c.ai.Installer.GetCluster(ctx, &installer.GetClusterParams{ClusterID: c.clusterId})
 	if err != nil {
-		return nil, err
+		return nil, aserror.GetAssistedError(err)
 	}
 
 	return cluster.Payload, nil
 }
 
-func (c *inventoryClient) GetClusterMonitoredOperator(ctx context.Context, clusterId, operatorName string) (*models.MonitoredOperator, error) {
-	monitoredOperators, err := c.ai.Operators.ListOfClusterOperators(ctx, &operators.ListOfClusterOperatorsParams{
-		ClusterID:    strfmt.UUID(clusterId),
-		OperatorName: &operatorName,
-	})
-	if err != nil {
-		return nil, aserror.GetAssistedError(err)
-	}
-
-	return monitoredOperators.Payload[0], nil
-}
-
-func (c *inventoryClient) GetClusterMonitoredOLMOperators(ctx context.Context, clusterId string) ([]models.MonitoredOperator, error) {
-	monitoredOperators, err := c.ai.Operators.ListOfClusterOperators(ctx, &operators.ListOfClusterOperatorsParams{ClusterID: strfmt.UUID(clusterId)})
-	if err != nil {
-		return nil, aserror.GetAssistedError(err)
-	}
-
-	olmOperators := make([]models.MonitoredOperator, 0)
-	for _, operator := range monitoredOperators.Payload {
-		if operator.OperatorType == models.OperatorTypeOlm {
-			olmOperators = append(olmOperators, *operator)
-		}
-	}
-
-	return olmOperators, nil
-}
-
 func (c *inventoryClient) GetEnabledHostsNamesHosts(ctx context.Context, log logrus.FieldLogger) (map[string]HostData, error) {
 	return c.GetHosts(ctx, log, []string{models.HostStatusDisabled})
 }
@@ -291,10 +256,10 @@ func (c *inventoryClient) createDownloadParams(filename string) *installer.Downl
 	}
 }
 
-func (c *inventoryClient) createUpdateHostInstallProgressParams(infraEnvId, hostId string, newStage models.HostStage, info string) *installer.V2UpdateHostInstallProgressParams {
-	return &installer.V2UpdateHostInstallProgressParams{
-		InfraEnvID: strfmt.UUID(infraEnvId),
-		HostID:     strfmt.UUID(hostId),
+func (c *inventoryClient) createUpdateHostInstallProgressParams(hostId string, newStage models.HostStage, info string) *installer.UpdateHostInstallProgressParams {
+	return &installer.UpdateHostInstallProgressParams{
+		ClusterID: c.clusterId,
+		HostID:    strfmt.UUID(hostId),
 		HostProgress: &models.HostProgress{
 			CurrentStage: newStage,
 			ProgressInfo: info,
@@ -338,39 +303,10 @@ func (c *inventoryClient) UploadLogs(ctx context.Context, clusterId string, logs
 	return aserror.GetAssistedError(err)
 }
 
-func (c *inventoryClient) ClusterLogProgressReport(ctx context.Context, clusterId string, progress models.LogsState) {
-	_, err := c.ai.Installer.UpdateClusterLogsProgress(ctx, &installer.UpdateClusterLogsProgressParams{
-		ClusterID: strfmt.UUID(clusterId),
-		LogsProgressParams: &models.LogsProgressParams{
-			LogsState: progress,
-		},
-	})
-	if err != nil {
-		c.logger.WithError(err).Errorf("failed to report log progress %s on cluster", progress)
-	}
-}
-
-func (c *inventoryClient) HostLogProgressReport(ctx context.Context, clusterId string, hostId string, progress models.LogsState) {
-	_, err := c.ai.Installer.UpdateHostLogsProgress(ctx, &installer.UpdateHostLogsProgressParams{
-		ClusterID: strfmt.UUID(clusterId),
-		HostID:    strfmt.UUID(hostId),
-		LogsProgressParams: &models.LogsProgressParams{
-			LogsState: progress,
-		},
-	})
-	if err != nil {
-		c.logger.WithError(err).Errorf("failed to report log progress %s on host %s", progress, hostId)
-	}
-}
-
-func (c *inventoryClient) UpdateClusterOperator(ctx context.Context, clusterId string, operatorName string, operatorStatus models.OperatorStatus, operatorStatusInfo string) error {
-	_, err := c.ai.Operators.ReportMonitoredOperatorStatus(ctx, &operators.ReportMonitoredOperatorStatusParams{
-		ClusterID: c.clusterId,
-		ReportParams: &models.OperatorMonitorReport{
-			Name:       operatorName,
-			Status:     operatorStatus,
-			StatusInfo: operatorStatusInfo,
-		},
+func (c *inventoryClient) UpdateClusterInstallProgress(ctx context.Context, clusterId string, progress string) error {
+	_, err := c.ai.Installer.UpdateClusterInstallProgress(ctx, &installer.UpdateClusterInstallProgressParams{
+		ClusterID:       strfmt.UUID(clusterId),
+		ClusterProgress: progress,
 	})
 	return aserror.GetAssistedError(err)
 }
