@@ -43,6 +43,8 @@ type Ops interface {
 	ReloadHostFile(filepath string) error
 	CreateOpenshiftSshManifest(filePath, template, sshPubKeyPath string) error
 	GetMustGatherLogs(workDir string, kubeconfigPath string) (string, error)
+	CreateRandomHostname(hostname string) error
+	GetHostname() (string, error)
 }
 
 const (
@@ -266,6 +268,7 @@ func (o *ops) renderControllerCm() error {
 		"ClusterId":            config.GlobalConfig.ClusterID,
 		"SkipCertVerification": strconv.FormatBool(config.GlobalConfig.SkipCertVerification),
 		"CACertPath":           config.GlobalConfig.CACertPath,
+		"HaMode":               config.GlobalConfig.HighAvailabilityMode,
 	}
 
 	return o.renderDeploymentFiles(filepath.Join(controllerDeployFolder, controllerDeployCmTemplate),
@@ -283,8 +286,9 @@ func (o *ops) renderControllerSecret() error {
 
 func (o *ops) renderControllerPod() error {
 	var params = map[string]interface{}{
-		"ControllerImage": config.GlobalConfig.ControllerImage,
-		"CACertPath":      config.GlobalConfig.CACertPath,
+		"ControllerImage":  config.GlobalConfig.ControllerImage,
+		"CACertPath":       config.GlobalConfig.CACertPath,
+		"OpenshiftVersion": config.GlobalConfig.OpenshiftVersion,
 	}
 
 	if config.GlobalConfig.ServiceIPs != "" {
@@ -401,7 +405,7 @@ func (o *ops) GetMCSLogs() (string, error) {
 
 func (o *ops) UploadInstallationLogs(isBootstrap bool) (string, error) {
 	command := "podman"
-	args := []string{"run", "--rm", "--privileged", "--net=host", "-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
+	args := []string{"run", "--rm", "--privileged", "--net=host", "--pid=host", "-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
 		"-v", "/var/log:/var/log", config.GlobalConfig.AgentImage, "logs_sender",
 		"-cluster-id", config.GlobalConfig.ClusterID, "-url", config.GlobalConfig.URL,
 		"-host-id", config.GlobalConfig.HostID,
@@ -501,3 +505,14 @@ func (o *ops) GetMustGatherLogs(workDir string, kubeconfigPath string) (string,
 	}
 	return path.Join(workDir, tarName), nil
 }
+
+func (o *ops) CreateRandomHostname(hostname string) error {
+	command := fmt.Sprintf("echo %s > /etc/hostname", hostname)
+	o.log.Infof("create random hostname with command %s", command)
+	_, err := o.ExecPrivilegeCommand(o.logWriter, "bash", "-c", command)
+	return err
+}
+
+func (o *ops) GetHostname() (string, error) {
+	return os.Hostname()
+}
