@@ -14,16 +14,15 @@ import (
 
 	"github.com/openshift/assisted-service/pkg/requestid"
 
-	"github.com/openshift/assisted-installer-agent/pkg/journalLogger"
 	"github.com/pkg/errors"
+
+	"github.com/openshift/assisted-installer-agent/pkg/journalLogger"
 	"golang.org/x/net/http/httpproxy"
 
-	ignition "github.com/coreos/ignition/v2/config"
+	ignition "github.com/coreos/ignition/v2/config/v3_1"
 	"github.com/openshift/assisted-service/models"
 
 	"github.com/hashicorp/go-version"
-	configv1 "github.com/openshift/api/config/v1"
-	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
 	"github.com/sirupsen/logrus"
 	"github.com/vincent-petithory/dataurl"
 )
@@ -98,7 +97,7 @@ func GetFileContentFromIgnition(ignitionData []byte, fileName string) ([]byte, e
 			return pullSecret.Data, nil
 		}
 	}
-	return nil, fmt.Errorf("path %s not found in ignition", fileName)
+	return nil, fmt.Errorf("path %s found in ignition", fileName)
 }
 
 func FindFiles(root string, mode WalkMode, pattern string) ([]string, error) {
@@ -156,7 +155,7 @@ func FindAndRemoveElementFromStringList(s []string, r string) []string {
 }
 
 func Retry(attempts int, sleep time.Duration, log *logrus.Logger, f func() error) (err error) {
-	for i := 0; i < attempts-1; i++ {
+	for i := 0; i < attempts; i++ {
 		err = f()
 		if err == nil {
 			return
@@ -164,11 +163,6 @@ func Retry(attempts int, sleep time.Duration, log *logrus.Logger, f func() error
 		time.Sleep(sleep)
 		log.Warnf("Retrying after error: %s", err)
 	}
-	// Don't wait after the last retry
-	err = f()
-	if err == nil {
-		return
-	}
 	return fmt.Errorf("failed after %d attempts, last error: %s", attempts, err)
 }
 
@@ -186,48 +180,24 @@ func GetHostIpsFromInventory(inventory *models.Inventory) ([]string, error) {
 	return ips, nil
 }
 
-func WaitForPredicateWithTimer(ctx context.Context, timeout time.Duration, interval time.Duration, predicate func(timer *time.Timer) bool) error {
-	timeoutTimer := time.NewTimer(timeout)
+func WaitForPredicate(timeout time.Duration, interval time.Duration, predicate func() bool) error {
+	timeoutAfter := time.After(timeout)
 	ticker := time.NewTicker(interval)
-
-	defer func() {
-		timeoutTimer.Stop()
-		ticker.Stop()
-	}()
-
 	// Keep trying until we're time out or get true
 	for {
 		select {
-		case <-ctx.Done():
-			return ctx.Err()
 		// Got a timeout! fail with a timeout error
-		case <-timeoutTimer.C:
+		case <-timeoutAfter:
 			return errors.New("timed out")
 		// Got a tick, we should check on checkSomething()
 		case <-ticker.C:
-			if predicate(timeoutTimer) {
+			if predicate() {
 				return nil
 			}
 		}
 	}
 }
 
-func WaitForPredicate(timeout time.Duration, interval time.Duration, predicate func() bool) error {
-	return WaitForPredicateWithContext(context.TODO(), timeout, interval, predicate)
-}
-
-func WaitForPredicateWithContext(ctx context.Context, timeout time.Duration, interval time.Duration, predicate func() bool) error {
-	return WaitForPredicateWithTimer(ctx, timeout, interval, func(timer *time.Timer) bool {
-		return predicate()
-	})
-}
-
-func WaitForPredicateParamsWithContext(ctx context.Context, timeout time.Duration, interval time.Duration, predicate func(arg interface{}) bool, arg interface{}) error {
-	return WaitForPredicateWithTimer(ctx, timeout, interval, func(timer *time.Timer) bool {
-		return predicate(arg)
-	})
-}
-
 // ProxyFromEnvVars provides an alternative to http.ProxyFromEnvironment since it is being initialized only
 // once and that happens by k8s before proxy settings was obtained. While this is no issue for k8s, it prevents
 // any out-of-cluster traffic from using the proxy
@@ -261,7 +231,7 @@ func RequestIDLogger(ctx context.Context, log *logrus.Logger) logrus.FieldLogger
 	return requestid.RequestIDLogger(log, requestid.FromContext(ctx))
 }
 
-func IsVersionLessThan47(openshiftVersion string) (bool, error) {
+func EtcdPatchRequired(openshiftVersion string) (bool, error) {
 	clusterVersion, err := version.NewVersion(openshiftVersion)
 	if err != nil {
 		return false, err
@@ -273,34 +243,3 @@ func IsVersionLessThan47(openshiftVersion string) (bool, error) {
 
 	return clusterVersion.LessThan(v47), nil
 }
-
-func EtcdPatchRequired(openshiftVersion string) (bool, error) {
-	return IsVersionLessThan47(openshiftVersion)
-}
-
-func CsvStatusToOperatorStatus(csvStatus string) models.OperatorStatus {
-	switch csvStatus {
-	case string(operatorsv1alpha1.CSVPhaseSucceeded):
-		return models.OperatorStatusAvailable
-	case string(operatorsv1alpha1.CSVPhaseFailed):
-		return models.OperatorStatusFailed
-	default:
-		return models.OperatorStatusProgressing
-	}
-}
-
-func ClusterOperatorConditionsToMonitoredOperatorStatus(conditions []configv1.ClusterOperatorStatusCondition) (models.OperatorStatus, string) {
-	for _, condition := range conditions {
-		if condition.Type == configv1.OperatorAvailable && condition.Status == configv1.ConditionTrue {
-			return models.OperatorStatusAvailable, condition.Message
-		}
-		if condition.Type == configv1.OperatorProgressing && condition.Status == configv1.ConditionTrue {
-			return models.OperatorStatusProgressing, condition.Message
-		}
-		if condition.Type == configv1.OperatorDegraded && condition.Status == configv1.ConditionTrue {
-			return models.OperatorStatusFailed, condition.Message
-		}
-	}
-
-	return models.OperatorStatusProgressing, ""
-}
